@@ -1,3 +1,4 @@
+import os
 import time
 import sys
 import random
@@ -12,8 +13,10 @@ STR_TYPE = "str"
 BOOL_TYPE = "bool"
 FLOAT_TYPE = "flt"
 
+PLTFRM = sys.platform
 
-def typing_print(message: str):
+
+def typing_print(message: str, *args, **kwargs):
     """
     Description:
         Simulates the typing of a keyboard with a given message
@@ -26,11 +29,11 @@ def typing_print(message: str):
         else:
             sleep = random.randrange(TIMING_RANGE_LOW, TIMING_RANGE_HIGH) / TIMING_DIVISOR
             time.sleep(sleep)
-        print(char, end="", flush=True)
-    print("\n", end="", flush=True)
+        print(char, end="", flush=True, *args, **kwargs)
+    print("\n", end="", flush=True, *args, **kwargs)
 
 
-def get_user_input(message: str, expected_type: str, can_cancel: bool = True, print_func=print):
+def get_user_input(message: str, expected_type: str, can_cancel: bool = True, print_func=print, allow_newlines: bool = True, *args, **kwargs):
     """
     Description:
         get user input and returns the expected datatype
@@ -40,7 +43,7 @@ def get_user_input(message: str, expected_type: str, can_cancel: bool = True, pr
     :param print_func: the function to which the messages be printed
     :return: The data in the type equal to expected_type or None if the user cancels
     """
-    print_func(message)
+    print_func(message, *args, **kwargs)
     data = input(">>> ")
     if data.lower() in ("cancel", "", "cancel."):
         if can_cancel:
@@ -55,6 +58,8 @@ def get_user_input(message: str, expected_type: str, can_cancel: bool = True, pr
             return get_user_input(message, expected_type, can_cancel, print_func)
         return data
     elif expected_type == STR_TYPE:
+        if allow_newlines:
+            data = _parse_string_mods(data)
         return data
     elif expected_type == BOOL_TYPE:
         if data.lower() in ("n", "no", "nope", "0", "false", "nah"):
@@ -87,3 +92,23 @@ def convert_string_to_float(data: str):
     fract = int(fract)
     fract /= 10 ** flen
     return fract + base
+
+
+def set_term_title(name: str):
+    if PLTFRM in ("linux", "darwin"):
+        sys.stdout.write(f"\x1b]2;{name}\x07")
+    elif PLTFRM in ("win32", "cygwin"):
+        os.system(f"title {name}")
+    else:
+        raise NotImplementedError
+
+
+def _parse_string_mods(string: str):
+    data = ""
+    if len(string.split("\\t")) != 0:
+        for i in string.split("\\n"):
+            data = f"{data}\n{i}"
+    if len(string.split("\\t")) != 0:
+        for i in data.split("\\t"):
+            data = f"{data}\t{i}"
+    return data
\ No newline at end of file
